@@ -5,12 +5,20 @@ import os
 from datetime import datetime
 # This file defines variables that can be accessed globally.
 
+
+# TODO: fix type conversion upon importing uint8 .mrc file
+# todo fix error where bakestack freezes baking a second time. 230120 - fixed, maybe?
+# TODO: fix snapping in editor input
+
 frozen = False
 root = ""
 app_name = "scNodes"
-version = "1.0.64"
+version = "1.1.1"
 license = "GNU GPL v3"
 logpath = "scNodes.log"
+filetype_project = ".scnp"
+filetype_node_setup = ".scn"
+filetype_scene = ".scnscene"
 nodes = list()
 active_node = None
 focused_node = None
@@ -44,6 +52,7 @@ batch_size = n_cpus_max
 image_viewer = None
 node_editor = None
 correlation_editor = None
+ce_tool_menu_names = {'Transform': True, 'Visuals': True, 'Export': False, 'Measure': False, 'Plugins': False, 'Particle picking': True}
 node_editor_relink = False
 correlation_editor_relink = False
 pickle_temp = dict()
@@ -56,9 +65,9 @@ ce_active_frame = None
 ce_clear_colour = (1.0, 1.0, 1.0, 1.0)
 ce_default_pixel_size = 64.0
 ce_flip_on_load = False
-ce_flip_mrc_on_load = False
 ce_selected_position = [0, 0]
 ce_va_subdivision = 8
+
 def set_active_node(node, keep_active=False):
     global focused_node, active_node, next_active_node
     """
@@ -93,24 +102,21 @@ def set_error(error_object, error_message):
     error_new = True
     error_logged = False
 
-def save_project(filename):
-    ## TODO change to work with new json export mode
-    if filename[-5:] == '.srnp':
-        filename = filename[:-5]
-    with open(filename+'.srnp', 'wb') as pickle_file:
-        pickle.dump([nodes, ce_frames], pickle_file)
+def save_scene(filename):
+    if not filetype_scene in filename:
+        filename += filetype_scene
+    with open(filename, 'wb') as pickle_file:
+        pickle.dump(ce_frames, pickle_file)
 
-def load_project(filename):
-    global nodes, ce_frames, correlation_editor_relink, node_editor_relink
+def load_scene(filename):
+    global ce_frames, correlation_editor_relink
     try:
         with open(filename, 'rb') as pickle_file:
-            data = pickle.load(pickle_file)
-            nodes = data[0]
-            ce_frames = data[1]
-            node_editor_relink = True
+            ce_frames = pickle.load(pickle_file)
             correlation_editor_relink = True
     except Exception as e:
-        set_error(e, "Error loading project")
+        set_error(e, "Error loading scene")
+
 
 def write_to_log(text):
     with open(root+logpath, "a") as f:
