@@ -113,8 +113,8 @@ class NodeEditor:
         # Render nodes  - render active_connector_parent_node first, to enable all other connectors' drop targets.
         source_node_id = -1
         if cfg.active_connector_parent_node is not None:
-            cfg.active_connector_parent_node.render()
             source_node_id = cfg.active_connector_parent_node.id
+            cfg.active_connector_parent_node.render()
         for node in cfg.nodes:
             if node.id is not source_node_id:
                 node.render()
@@ -157,9 +157,6 @@ class NodeEditor:
         def ww_context_menu():
             imgui.push_style_color(imgui.COLOR_POPUP_BACKGROUND, *cfg.COLOUR_MENU_WINDOW_BACKGROUND)
             if imgui.begin_popup_context_window():
-                raise_error, _ = imgui.menu_item("Raise error (debug)")
-                if raise_error:
-                    raise cfg.error_obj
                 copy_error, _ = imgui.menu_item("Copy to clipboard")
                 if copy_error:
                     pyperclip.copy(cfg.error_msg)
@@ -241,54 +238,37 @@ class NodeEditor:
         imgui.push_style_color(imgui.COLOR_HEADER_ACTIVE, *cfg.COLOUR_MAIN_MENU_BAR_HILIGHT)
         imgui.push_style_color(imgui.COLOR_HEADER, *cfg.COLOUR_MAIN_MENU_BAR_HILIGHT)
         imgui.push_style_color(imgui.COLOR_POPUP_BACKGROUND, *cfg.COLOUR_MENU_WINDOW_BACKGROUND)
+        imgui.push_style_var(imgui.STYLE_FRAME_PADDING, (2.0, 2.0))
         ## Save node setup.
         if imgui.core.begin_main_menu_bar():
             if imgui.begin_menu('File'):
-                if imgui.begin_menu("Project"):
-                    if imgui.menu_item("Save project")[0]:
-                        try:
-                            filename = filedialog.asksaveasfilename(filetypes=[("scNodes project", ".scnp")])
-                            if filename != '':
-                                cfg.save_project(filename)
-                        except Exception as e:
-                            cfg.set_error(e, f"Error saving project\n")
-                    if imgui.menu_item("Load project")[0]:
-                        try:
-                            filename = filedialog.askopenfilename(filetypes=[("scNodes project", ".scnp")])
-                            if filename != '':
-                                cfg.load_project(filename)
-                        except Exception as e:
-                            cfg.set_error(e, f"Error loading project:\n")
-                    imgui.end_menu()
-                if imgui.begin_menu("Node Editor"):
-                    save_setup, _ = imgui.menu_item("Save setup")
-                    if save_setup:
-                        filename = filedialog.asksaveasfilename(filetypes=[("scNodes setup", ".scn")])
+                save_setup, _ = imgui.menu_item("Save setup")
+                if save_setup:
+                    filename = filedialog.asksaveasfilename(filetypes=[("scNodes setup", ".scn")])
+                    if filename != '':
+                        NodeEditor.save_node_setup(filename)
+                load_setup, _ = imgui.menu_item("Load setup")
+                if load_setup:
+                    try:
+                        filename = filedialog.askopenfilename(filetypes=[("scNodes setup", ".scn")])
                         if filename != '':
-                            NodeEditor.save_node_setup(filename + ".scn")
-                    load_setup, _ = imgui.menu_item("Load setup")
-                    if load_setup:
-                        try:
-                            filename = filedialog.askopenfilename(filetypes=[("scNodes setup", ".scn")])
-                            if filename != '':
-                                cfg.nodes = list()
-                                NodeEditor.append_node_setup(filename)
-                        except Exception as e:
-                            cfg.set_error(e, f"Error loading node setup:\n"+str(e))
-                    import_setup, _ = imgui.menu_item("Load setup & append")
-                    if import_setup:
-                        try:
-                            filename = filedialog.askopenfilename(filetypes=[("scNodes setup", ".scn")])
-                            if filename != '':
-                                NodeEditor.append_node_setup(filename)
-                        except Exception as e:
-                            cfg.set_error(e, "Error importing node setup:\n"+str(e))
-                    clear_setup, _ = imgui.menu_item("Clear setup")
-                    if clear_setup:
-                        for i in range(len(cfg.nodes)):
-                            cfg.nodes[0].delete()
-                        cfg.nodes = list()
-                    imgui.end_menu()
+                            cfg.nodes = list()
+                            NodeEditor.append_node_setup(filename)
+                    except Exception as e:
+                        cfg.set_error(e, f"Error loading node setup:\n"+str(e))
+                import_setup, _ = imgui.menu_item("Append setup")
+                if import_setup:
+                    try:
+                        filename = filedialog.askopenfilename(filetypes=[("scNodes setup", ".scn")])
+                        if filename != '':
+                            NodeEditor.append_node_setup(filename)
+                    except Exception as e:
+                        cfg.set_error(e, "Error importing node setup:\n"+str(e))
+                clear_setup, _ = imgui.menu_item("Clear setup")
+                if clear_setup:
+                    for i in range(len(cfg.nodes)):
+                        cfg.nodes[0].delete()
+                    cfg.nodes = list()
                 imgui.end_menu()
             if imgui.begin_menu('Settings'):
                 install_node, _ = imgui.menu_item("Install a node")
@@ -322,6 +302,7 @@ class NodeEditor:
                 imgui.end_menu()
             imgui.end_main_menu_bar()
         imgui.pop_style_color(6)
+        imgui.pop_style_var(1)
 
     @staticmethod
     def install_node():
@@ -394,52 +375,63 @@ class NodeEditor:
 
     @staticmethod
     def save_node_setup(path):
-        node_setup = list()
-        for node in cfg.nodes:
-            node_setup.append(node.to_dict())
-        links = list()
-        for node in cfg.nodes:
-            for home_attribute in node.connectable_attributes.values():
-                if home_attribute.direction == ConnectableAttribute.INPUT:
-                    continue
-                for partner_attribute in home_attribute.linked_attributes:
-                    links.append([home_attribute.id, partner_attribute.id])
+        if path[-len(cfg.filetype_node_setup):] != cfg.filetype_node_setup:
+            path+=cfg.filetype_node_setup
+        try:
+            node_setup = list()
+            for node in cfg.nodes:
+                node_setup.append(node.to_dict())
+            links = list()
+            for node in cfg.nodes:
+                for home_attribute in node.connectable_attributes.values():
+                    if home_attribute.direction == ConnectableAttribute.INPUT:
+                        continue
+                    for partner_attribute in home_attribute.linked_attributes:
+                        links.append([home_attribute.id, partner_attribute.id])
 
-        full_setup = dict()
-        full_setup["nodes"] = node_setup
-        full_setup["links"] = links
-        with open(path, 'w') as outfile:
-            json.dump(full_setup, outfile, indent=2)
+            full_setup = dict()
+            full_setup["nodes"] = node_setup
+            full_setup["links"] = links
+            print(full_setup)
+            print(node_setup)
+            print(links)
+            with open(path, 'w') as outfile:
+                json.dump(full_setup, outfile, indent=2)
+        except Exception as e:
+            cfg.set_error(e, "Error saving node setup")
 
 
     @staticmethod
     def append_node_setup(path):
-        with open(path, 'r') as infile:
-            full_setup = json.load(infile)
-            # parse the node setup
-            node_setup = full_setup["nodes"]
-            new_nodes = list()
-            for node_dict in node_setup:
-                # generate a node of the right type:
-                title = node_dict["title"]
-                new_node = NodeEditor.NODE_FACTORY[title]()
-                new_node.from_dict(node_dict)
-                new_nodes.append(new_node)
-            # with all the nodes and their attributes added, link up the attributes:
-            all_attributes_by_id = dict()
-            for node in cfg.nodes:
-                for a in node.connectable_attributes.values():
-                    if a.id in node.connectable_attributes:
-                        cfg.set_error(BaseException(), "Error appending node setup - an id was used multiple times.")
-                    all_attributes_by_id[a.id] = a
-            links = full_setup["links"]
-            for link in links:
-                home_attribute = all_attributes_by_id[link[0]]
-                parent_attribute = all_attributes_by_id[link[1]]
-                home_attribute.connect_attributes(parent_attribute)
-            # finally, call all of the new nodes' on_load function
-            for node in new_nodes:
-                node.on_load()
+        try:
+            with open(path, 'r') as infile:
+                full_setup = json.load(infile)
+                # parse the node setup
+                node_setup = full_setup["nodes"]
+                new_nodes = list()
+                for node_dict in node_setup:
+                    # generate a node of the right type:
+                    title = node_dict["title"]
+                    new_node = NodeEditor.NODE_FACTORY[title]()
+                    new_node.from_dict(node_dict)
+                    new_nodes.append(new_node)
+                # with all the nodes and their attributes added, link up the attributes:
+                all_attributes_by_id = dict()
+                for node in cfg.nodes:
+                    for a in node.connectable_attributes.values():
+                        if a.id in node.connectable_attributes:
+                            cfg.set_error(BaseException(), "Error appending node setup - an id was used multiple times.")
+                        all_attributes_by_id[a.id] = a
+                links = full_setup["links"]
+                for link in links:
+                    home_attribute = all_attributes_by_id[link[0]]
+                    parent_attribute = all_attributes_by_id[link[1]]
+                    home_attribute.connect_attributes(parent_attribute)
+                # finally, call all of the new nodes' on_load function
+                for node in new_nodes:
+                    node.on_load()
+        except Exception as e:
+            cfg.set_error(e, "Error appending/loading node setup: ")
 
 
     @staticmethod
@@ -467,7 +459,7 @@ class NodeEditor:
 
     @staticmethod
     def delete_temporary_files():
-        dirs = glob.glob("_srnodes_temp*/")
+        dirs = glob.glob("_SRNTEMP*/")
         for dir in dirs:
             shutil.rmtree(dir)
 
