@@ -1,4 +1,5 @@
 import colorcet as cc
+import numpy as np
 
 n_cpus = -1
 
@@ -12,7 +13,9 @@ luts = dict()
 luts["Gray"] = cc.linear_grey_0_100_c0
 luts["Red"] = cc.linear_ternary_red_0_50_c52
 luts["Green"] = cc.linear_kgy_5_95_c69
+luts["Green"][0] = [0.0, 0.0, 0.0]
 luts["Blue"] = cc.linear_kbc_5_95_c73
+luts["Blue"][0] = [0.0, 0.0, 0.0]
 luts["Fire"] = cc.linear_kryw_0_100_c71
 luts["Ice"] = cc.linear_blue_95_50_c20
 luts["Parula"] = cc.linear_bgyw_20_98_c66
@@ -22,7 +25,12 @@ luts["Neon"] = cc.linear_worb_100_25_c53
 #luts["Isoluminant hue"] = cc.isoluminant_cgo_80_c38
 luts["Over/under A"] = cc.diverging_linear_bjr_30_55_c53
 luts["Over/under B"] = cc.diverging_gwr_55_95_c38
-#luts["Glasbey"] = cc.glasbey_bw_minc_20_minl_30
+luts["Diverging green/red"] = np.zeros((256, 3))
+luts["Diverging magenta/cyan"] = np.zeros((256, 3))
+for i in range(256):
+    luts["Diverging green/red"][i, :] = [1.0 - i / 256, i / 256, 0.0]
+    luts["Diverging magenta/cyan"][i, :] = [1.0 - i / 256, i / 256, 1.0]
+luts["Glasbey"] = cc.glasbey_bw_minc_20_minl_30
 lut_names = list(luts.keys())
 
 def_img_size = (2048, 2048)
