@@ -18,7 +18,6 @@ class BakeStackNode(Node):
 
     RANGE_OPTIONS = ["All frames", "Custom range"]
 
-    ## todo fix error where bakestack freezes upon leaving entire node setup intact, changing source data node input to a different stack, then pressing GO on bake stack node.
     def __init__(self):
         super().__init__()
         self.size = 230
@@ -181,10 +180,8 @@ class BakeStackNode(Node):
                 else:
                     index = self.frames_to_bake[-1]
                     self.frames_to_bake.pop()
-                    coordinates = self.get_image_and_save(index)
+                    coordinates = [self.get_image_and_save(index)]
                     self.n_baked += 1
-                    # todo fix error where bakestack freezes baking a second time.
-                    # 230120 - fixed, maybe. todo: check
                 if self.params["bake_coordinates"]:
                     self.coordinates += coordinates  # coordinates is a list of lists. in the end, self.coordinates will be a list of length [amount of frames], with a sublist of xy coords for every img.
                 if cfg.profiling:
