@@ -1,7 +1,6 @@
 from scNodes.core.node import *
 from scNodes.core.reconstruction import *
 
-
 def create():
     return ReconstructionRendererNode()
 
@@ -88,8 +87,8 @@ class ReconstructionRendererNode(Node):
                 _c, self.params["parameter"] = imgui.combo("Parameter", self.params["parameter"], self.available_parameters)
                 if _c:
                     self.get_histogram_values()
-                    self.params["min"] = self.histogram_bins[0]
-                    self.params["max"] = self.histogram_bins[-1]
+                    self.params["min"] = float(self.histogram_bins[0])
+                    self.params["max"] = float(self.histogram_bins[-1])
                     self.paint_applied = False
                 imgui.set_next_item_width(_cw - 80)
                 _c, self.paint_by = imgui.combo("LUT", self.paint_by, settings.lut_names)
@@ -107,17 +106,16 @@ class ReconstructionRendererNode(Node):
                     if _max != _min:
                         _uv_left = 1.0 + (_l - _max) / (_max - _min)
                         _uv_right = 1.0 + (_h - _max) / (_max - _min)
-                    imgui.image(self.reconstructor.lut_texture.renderer_id, _cw, 10.0, (_uv_left, 0.5),
-                                (_uv_right, 0.5), border_color=(0.0, 0.0, 0.0, 1.0))
+                    imgui.image(self.reconstructor.lut_texture.renderer_id, _cw, 10.0, (_uv_left, 0.5), (_uv_right, 0.5), border_color=(0.0, 0.0, 0.0, 1.0))
                     imgui.push_item_width(_cw)
                     _c, self.params["min"] = imgui.slider_float("##min", self.params["min"], self.histogram_bins[0], self.histogram_bins[1],format='min: %.1f')
-                    if _c: self.paint_applied = False
+                    if _c:
+                        self.paint_applied = False
                     _c, self.params["max"] = imgui.slider_float("##max", self.params["max"], self.histogram_bins[0], self.histogram_bins[1],format='max: %.1f')
-                    if _c: self.paint_applied = False
+                    if _c:
+                        self.paint_applied = False
                     imgui.pop_item_width()
 
-                # TODO: histogram
-
             if self.params["auto_render"]:
                 if self.any_change:
                     self.build_reconstruction()
@@ -184,22 +182,28 @@ class ReconstructionRendererNode(Node):
                     self.params["min"] = self.histogram_bins[0]
                     self.params["max"] = self.histogram_bins[-1]
 
-
     def apply_paint(self, particle_data):
         if cfg.profiling:
             time_start = time.time()
 
-        values = particle_data.parameter[self.available_parameters[self.params["parameter"]]]
-        i = 0
-        for particle in particle_data.particles:
-            particle.colour_idx = np.min([np.max([0.0, (values[i] - self.params["min"]) / (self.params["max"] - self.params["min"])]), 1.0])
-            i += 1
-        self.reconstructor.colours_set = False
+        values = particle_data.parameters[self.available_parameters[self.params["parameter"]]]
+        _min = self.params["min"]
+        _max = self.params["max"]
+        n_particles = particle_data.n_particles
+        _colour_idx = np.zeros(n_particles)
+        for i in range(particle_data.n_particles):
+            _colour_idx[i] = np.min([np.max([0.0, (values[i] - _min) / (_max - _min)]), 1.0])
+        particle_data.parameters["colour_idx"] = _colour_idx
+        self.reconstructor.colours_set = False  # tells the reconstructor to re-upload the particle_data colour array to the gpu.
         if cfg.profiling:
             self.profiler_time += time.time() - time_start
 
     def build_reconstruction(self):
         try:
+            roi = self.get_particle_data().reconstruction_roi
+            img_width = int((roi[3] - roi[1]) / self.params["pixel_size"])
+            img_height = int((roi[2] - roi[0]) / self.params["pixel_size"])
+            self.reconstruction_image_size = (img_width, img_height)
             self.original_pixel_size = Node.get_source_load_data_node(self).dataset.pixel_size
             self.reconstructor.set_pixel_size(self.params["pixel_size"])
             self.reconstructor.set_image_size(self.reconstruction_image_size)
@@ -210,7 +214,6 @@ class ReconstructionRendererNode(Node):
                 self.reconstructor.set_camera_origin([-particle_data.reconstruction_roi[0] / self.params["pixel_size"], -particle_data.reconstruction_roi[1] / self.params["pixel_size"]])
 
                 ## Apply colours
-                ## TODO: add option to output a monochrome channel
                 if self.paint_particles:
                     if not self.paint_applied:
                         self.apply_paint(particle_data)
@@ -218,21 +221,23 @@ class ReconstructionRendererNode(Node):
                         self.reconstructor.colours_set = False
                 else:
                     if not self.paint_applied:
-                        for particle in particle_data.particles:
-                            particle.colour_idx = 1.0
+                        particle_data.parameters["colour_idx"] = np.ones_like(particle_data.parameters["colour_idx"])
                         self.paint_applied = True
                         self.reconstructor.colours_set = False
                 if self.reconstructor.particle_data.empty:
                     return None
                 else:
                     self.latest_image = self.reconstructor.render(fixed_uncertainty=(self.params["default_sigma"] if self.params["fix_sigma"] else None))
-                    if not self.paint_particles:
-                        self.latest_image = self.latest_image[:, :, 0]  # single channel only for non-painted particles
+                    if not self.latest_image.any():
+                        self.latest_image = None
                     self.any_change = True
                     if self.paint_particles:
                         self.OVERRIDE_AUTOCONTRAST = True
                         clims = self.compute_contrast_lims(self.latest_image)
                         self.OVERRIDE_AUTOCONTRAST_LIMS = (clims[0], clims[1])
+                    else:
+                        if self.latest_image is not None:
+                            self.latest_image = self.latest_image[:, :, 0]
             else:
                 self.latest_image = None
         except Exception as e:
@@ -242,7 +247,7 @@ class ReconstructionRendererNode(Node):
     def compute_contrast_lims(rgb_image):
         max_channel = np.unravel_index(np.argmax(rgb_image), rgb_image.shape)[2]
         img_sorted = np.sort(rgb_image[:, :, max_channel].flatten())
-        n = img_sorted.shape[0] * img_sorted.shape[1]
+        n = img_sorted.shape[0]
         cmin = img_sorted[int(settings.autocontrast_saturation / 100.0 * n)]
         cmax = img_sorted[int((1.0 - settings.autocontrast_saturation / 100.0) * n)]
         return cmin, cmax
@@ -271,8 +276,8 @@ class ReconstructionRendererNode(Node):
         except Exception as e:
             cfg.set_error(e, f"Couldn't get particle data in {self.title} node.")
         if roi is not None:
-            img_width = int((roi[2] - roi[0]) / self.params["pixel_size"])  # TODO
-            img_height = int((roi[3] - roi[1]) / self.params["pixel_size"])
+            img_width = int((roi[3] - roi[1]) / self.params["pixel_size"])
+            img_height = int((roi[2] - roi[0]) / self.params["pixel_size"])
             self.reconstruction_image_size = (img_width, img_height)
 
     def pre_pickle_impl(self):
